==> jc-1.4.0.tar.gz: javax/swing/colorchooser/AbstractColorChooserPanel.h <==
// public abstract class javax.swing.colorchooser.AbstractColorChooserPanel

// class file dependencies
// @dep_class d547e55bb64f2ca8 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6c83b58ef8abc63e javax_swing_JComponent
// @dep_class 7c0c9df11a59950c javax_swing_JPanel
// @dep_class 6999b2dfcdbe6fcb javax_swing_colorchooser_AbstractColorChooserPanel

// header file dependencies
// @dep_header javax_swing_JPanel

#include "javax/swing/JPanel.h"

#ifndef _JC_javax_swing_colorchooser_AbstractColorChooserPanel_H_
#define _JC_javax_swing_colorchooser_AbstractColorChooserPanel_H_

// Forward structure declarations
struct _jc_java_awt_Color$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_Icon$object;
struct _jc_javax_swing_JColorChooser$object;
struct _jc_javax_swing_colorchooser_ColorSelectionModel$object;

// Typedefs
typedef struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$sub_refs	_jc_javax_swing_colorchooser_AbstractColorChooserPanel$sub_refs;
typedef struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$sub_nonrefs	_jc_javax_swing_colorchooser_AbstractColorChooserPanel$sub_nonrefs;
typedef struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$refs	_jc_javax_swing_colorchooser_AbstractColorChooserPanel$refs;
typedef struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$nonrefs	_jc_javax_swing_colorchooser_AbstractColorChooserPanel$nonrefs;
typedef struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$object	_jc_javax_swing_colorchooser_AbstractColorChooserPanel$object;

typedef struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$fields_struct	_jc_javax_swing_colorchooser_AbstractColorChooserPanel$fields_struct;
typedef const struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$vmethods	_jc_javax_swing_colorchooser_AbstractColorChooserPanel$vmethods;
typedef const struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$vtable	_jc_javax_swing_colorchooser_AbstractColorChooserPanel$vtable;
typedef const struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$vtype	_jc_javax_swing_colorchooser_AbstractColorChooserPanel$vtype;

// Class fields structure
struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_colorchooser_AbstractColorChooserPanel$fields_struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$class_fields;

// Constructors
extern void _jc_javax_swing_colorchooser_AbstractColorChooserPanel$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$object *);

// Virtual methods
extern void _jc_javax_swing_colorchooser_AbstractColorChooserPanel$method$buildChooser$c3b4ef0d06e57808(_jc_env *, struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$object *);
extern struct _jc_java_awt_Color$object *_jc_javax_swing_colorchooser_AbstractColorChooserPanel$method$getColorFromModel$08b62944ab4eb830(_jc_env *, struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$object *);
extern struct _jc_object *_jc_javax_swing_colorchooser_AbstractColorChooserPanel$method$getColorSelectionModel$d975a7dde8d0a17d(_jc_env *, struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$object *);
extern struct _jc_java_lang_String$object *_jc_javax_swing_colorchooser_AbstractColorChooserPanel$method$getDisplayName$ec8495f8bf7d85f4(_jc_env *, struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$object *);
extern struct _jc_object *_jc_javax_swing_colorchooser_AbstractColorChooserPanel$method$getLargeDisplayIcon$b8bd57d58f27db0a(_jc_env *, struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$object *);
extern struct _jc_object *_jc_javax_swing_colorchooser_AbstractColorChooserPanel$method$getSmallDisplayIcon$3f5a81cdb2c68338(_jc_env *, struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$object *);
extern void _jc_javax_swing_colorchooser_AbstractColorChooserPanel$method$installChooserPanel$d1ff7b77805e92b4(_jc_env *, struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$object *, struct _jc_javax_swing_JColorChooser$object *);
extern void _jc_javax_swing_colorchooser_AbstractColorChooserPanel$method$paint$76f038a09cf0c480(_jc_env *, struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$object *, struct _jc_java_awt_Graphics$object *);
extern void _jc_javax_swing_colorchooser_AbstractColorChooserPanel$method$uninstallChooserPanel$75ee74402cc2c672(_jc_env *, struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$object *, struct _jc_javax_swing_JColorChooser$object *);
extern void _jc_javax_swing_colorchooser_AbstractColorChooserPanel$method$updateChooser$ed0d27d69b57ccc5(_jc_env *, struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_colorchooser_AbstractColorChooserPanel$method_info$buildChooser$c3b4ef0d06e57808;
extern _jc_method _jc_javax_swing_colorchooser_AbstractColorChooserPanel$method_info$getColorFromModel$08b62944ab4eb830;
extern _jc_method _jc_javax_swing_colorchooser_AbstractColorChooserPanel$method_info$getColorSelectionModel$d975a7dde8d0a17d;
extern _jc_method _jc_javax_swing_colorchooser_AbstractColorChooserPanel$method_info$getDisplayName$ec8495f8bf7d85f4;
extern _jc_method _jc_javax_swing_colorchooser_AbstractColorChooserPanel$method_info$getLargeDisplayIcon$b8bd57d58f27db0a;
extern _jc_method _jc_javax_swing_colorchooser_AbstractColorChooserPanel$method_info$getSmallDisplayIcon$3f5a81cdb2c68338;
extern _jc_method _jc_javax_swing_colorchooser_AbstractColorChooserPanel$method_info$installChooserPanel$d1ff7b77805e92b4;
extern _jc_method _jc_javax_swing_colorchooser_AbstractColorChooserPanel$method_info$paint$76f038a09cf0c480;
extern _jc_method _jc_javax_swing_colorchooser_AbstractColorChooserPanel$method_info$uninstallChooserPanel$75ee74402cc2c672;
extern _jc_method _jc_javax_swing_colorchooser_AbstractColorChooserPanel$method_info$updateChooser$ed0d27d69b57ccc5;

// Virtual methods structure
struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$vmethods {
	void	(*buildChooser$c3b4ef0d06e57808)(_jc_env *, struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$object *);
	struct _jc_java_awt_Color$object	*(*getColorFromModel$08b62944ab4eb830)(_jc_env *, struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$object *);
	struct _jc_object	*(*getColorSelectionModel$d975a7dde8d0a17d)(_jc_env *, struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$object *);
	struct _jc_java_lang_String$object	*(*getDisplayName$ec8495f8bf7d85f4)(_jc_env *, struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$object *);
	struct _jc_object	*(*getLargeDisplayIcon$b8bd57d58f27db0a)(_jc_env *, struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$object *);
	struct _jc_object	*(*getSmallDisplayIcon$3f5a81cdb2c68338)(_jc_env *, struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$object *);
	void	(*installChooserPanel$d1ff7b77805e92b4)(_jc_env *, struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$object *, struct _jc_javax_swing_JColorChooser$object *);
	void	(*paint$76f038a09cf0c480)(_jc_env *, struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$object *, struct _jc_java_awt_Graphics$object *);
	void	(*uninstallChooserPanel$75ee74402cc2c672)(_jc_env *, struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$object *, struct _jc_javax_swing_JColorChooser$object *);
	void	(*updateChooser$ed0d27d69b57ccc5)(_jc_env *, struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$object *);
};

// Vtable
struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_javax_swing_JComponent$vmethods	javax_swing_JComponent;
	_jc_javax_swing_JPanel$vmethods	javax_swing_JPanel;
	_jc_javax_swing_colorchooser_AbstractColorChooserPanel$vmethods	javax_swing_colorchooser_AbstractColorChooserPanel;
};

// Vtype
struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$vtype {
	_jc_type			type;
	_jc_javax_swing_colorchooser_AbstractColorChooserPanel$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$sub_refs {
	struct _jc_javax_swing_JColorChooser$object	*chooser;
};

// Reference instance fields (object)
struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$refs {
    _jc_javax_swing_colorchooser_AbstractColorChooserPanel$sub_refs	javax_swing_colorchooser_AbstractColorChooserPanel;
    _jc_javax_swing_JPanel$sub_refs	javax_swing_JPanel;
    _jc_javax_swing_JComponent$sub_refs	javax_swing_JComponent;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_javax_swing_JComponent$sub_nonrefs	javax_swing_JComponent;
    _jc_javax_swing_JPanel$sub_nonrefs	javax_swing_JPanel;
    _jc_javax_swing_colorchooser_AbstractColorChooserPanel$sub_nonrefs	javax_swing_colorchooser_AbstractColorChooserPanel;
};

// Object instance structure
struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$object {
	_jc_javax_swing_colorchooser_AbstractColorChooserPanel$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_colorchooser_AbstractColorChooserPanel$vtype	*vtype;
	_jc_javax_swing_colorchooser_AbstractColorChooserPanel$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_colorchooser_AbstractColorChooserPanel$vtype _jc_javax_swing_colorchooser_AbstractColorChooserPanel$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_colorchooser_AbstractColorChooserPanel, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_colorchooser_AbstractColorChooserPanel$class_object;

#endif	/* _JC_javax_swing_colorchooser_AbstractColorChooserPanel_H_ */

==> jc-1.4.5.tar.gz: javax/swing/colorchooser/AbstractColorChooserPanel.h <==
// public abstract class javax.swing.colorchooser.AbstractColorChooserPanel

// class file dependencies
// @dep_class 5a2bf6e9db456f42 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c84352ee73c7cec1 javax_swing_JComponent
// @dep_class 7c0c9df11a59950c javax_swing_JPanel
// @dep_class 6999b2dfcdbe6fcb javax_swing_colorchooser_AbstractColorChooserPanel

// header file dependencies
// @dep_header javax_swing_JPanel

#include "javax/swing/JPanel.h"

#ifndef _JC_javax_swing_colorchooser_AbstractColorChooserPanel_H_
#define _JC_javax_swing_colorchooser_AbstractColorChooserPanel_H_

// Forward structure declarations
struct _jc_java_awt_Color$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_Icon$object;
struct _jc_javax_swing_JColorChooser$object;
struct _jc_javax_swing_colorchooser_ColorSelectionModel$object;

// Typedefs
typedef struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$sub_refs	_jc_javax_swing_colorchooser_AbstractColorChooserPanel$sub_refs;
typedef struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$sub_nonrefs	_jc_javax_swing_colorchooser_AbstractColorChooserPanel$sub_nonrefs;
typedef struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$refs	_jc_javax_swing_colorchooser_AbstractColorChooserPanel$refs;
typedef struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$nonrefs	_jc_javax_swing_colorchooser_AbstractColorChooserPanel$nonrefs;
typedef struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$object	_jc_javax_swing_colorchooser_AbstractColorChooserPanel$object;

typedef struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$fields_struct	_jc_javax_swing_colorchooser_AbstractColorChooserPanel$fields_struct;
typedef const struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$vmethods	_jc_javax_swing_colorchooser_AbstractColorChooserPanel$vmethods;
typedef const struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$vtable	_jc_javax_swing_colorchooser_AbstractColorChooserPanel$vtable;
typedef const struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$vtype	_jc_javax_swing_colorchooser_AbstractColorChooserPanel$vtype;

// Class fields structure
struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_colorchooser_AbstractColorChooserPanel$fields_struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$class_fields;

// Constructors
extern void _jc_javax_swing_colorchooser_AbstractColorChooserPanel$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_colorchooser_AbstractColorChooserPanel$method$buildChooser$c3b4ef0d06e57808(_jc_env *, struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Color$object *_jc_javax_swing_colorchooser_AbstractColorChooserPanel$method$getColorFromModel$08b62944ab4eb830(_jc_env *, struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_swing_colorchooser_AbstractColorChooserPanel$method$getColorSelectionModel$d975a7dde8d0a17d(_jc_env *, struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_swing_colorchooser_AbstractColorChooserPanel$method$getDisplayName$ec8495f8bf7d85f4(_jc_env *, struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_swing_colorchooser_AbstractColorChooserPanel$method$getLargeDisplayIcon$b8bd57d58f27db0a(_jc_env *, struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_swing_colorchooser_AbstractColorChooserPanel$method$getSmallDisplayIcon$3f5a81cdb2c68338(_jc_env *, struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_colorchooser_AbstractColorChooserPanel$method$installChooserPanel$d1ff7b77805e92b4(_jc_env *, struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$object *, struct _jc_javax_swing_JColorChooser$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_colorchooser_AbstractColorChooserPanel$method$paint$76f038a09cf0c480(_jc_env *, struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$object *, struct _jc_java_awt_Graphics$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_colorchooser_AbstractColorChooserPanel$method$uninstallChooserPanel$75ee74402cc2c672(_jc_env *, struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$object *, struct _jc_javax_swing_JColorChooser$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_colorchooser_AbstractColorChooserPanel$method$updateChooser$ed0d27d69b57ccc5(_jc_env *, struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_colorchooser_AbstractColorChooserPanel$method_info$buildChooser$c3b4ef0d06e57808;
extern _jc_method _jc_javax_swing_colorchooser_AbstractColorChooserPanel$method_info$getColorFromModel$08b62944ab4eb830;
extern _jc_method _jc_javax_swing_colorchooser_AbstractColorChooserPanel$method_info$getColorSelectionModel$d975a7dde8d0a17d;
extern _jc_method _jc_javax_swing_colorchooser_AbstractColorChooserPanel$method_info$getDisplayName$ec8495f8bf7d85f4;
extern _jc_method _jc_javax_swing_colorchooser_AbstractColorChooserPanel$method_info$getLargeDisplayIcon$b8bd57d58f27db0a;
extern _jc_method _jc_javax_swing_colorchooser_AbstractColorChooserPanel$method_info$getSmallDisplayIcon$3f5a81cdb2c68338;
extern _jc_method _jc_javax_swing_colorchooser_AbstractColorChooserPanel$method_info$installChooserPanel$d1ff7b77805e92b4;
extern _jc_method _jc_javax_swing_colorchooser_AbstractColorChooserPanel$method_info$paint$76f038a09cf0c480;
extern _jc_method _jc_javax_swing_colorchooser_AbstractColorChooserPanel$method_info$uninstallChooserPanel$75ee74402cc2c672;
extern _jc_method _jc_javax_swing_colorchooser_AbstractColorChooserPanel$method_info$updateChooser$ed0d27d69b57ccc5;

// Virtual methods structure
struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$vmethods {
	void	(*buildChooser$c3b4ef0d06e57808)(_jc_env *, struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_Color$object	*(*getColorFromModel$08b62944ab4eb830)(_jc_env *, struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getColorSelectionModel$d975a7dde8d0a17d)(_jc_env *, struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getDisplayName$ec8495f8bf7d85f4)(_jc_env *, struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getLargeDisplayIcon$b8bd57d58f27db0a)(_jc_env *, struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getSmallDisplayIcon$3f5a81cdb2c68338)(_jc_env *, struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$object *) _JC_JCNI_ATTR;
	void	(*installChooserPanel$d1ff7b77805e92b4)(_jc_env *, struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$object *, struct _jc_javax_swing_JColorChooser$object *) _JC_JCNI_ATTR;
	void	(*paint$76f038a09cf0c480)(_jc_env *, struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$object *, struct _jc_java_awt_Graphics$object *) _JC_JCNI_ATTR;
	void	(*uninstallChooserPanel$75ee74402cc2c672)(_jc_env *, struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$object *, struct _jc_javax_swing_JColorChooser$object *) _JC_JCNI_ATTR;
	void	(*updateChooser$ed0d27d69b57ccc5)(_jc_env *, struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_javax_swing_JComponent$vmethods	javax_swing_JComponent;
	_jc_javax_swing_JPanel$vmethods	javax_swing_JPanel;
	_jc_javax_swing_colorchooser_AbstractColorChooserPanel$vmethods	javax_swing_colorchooser_AbstractColorChooserPanel;
};

// Vtype
struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$vtype {
	_jc_type			type;
	_jc_javax_swing_colorchooser_AbstractColorChooserPanel$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$sub_refs {
	struct _jc_javax_swing_JColorChooser$object	*chooser;
};

// Reference instance fields (object)
struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$refs {
    _jc_javax_swing_colorchooser_AbstractColorChooserPanel$sub_refs	javax_swing_colorchooser_AbstractColorChooserPanel;
    _jc_javax_swing_JPanel$sub_refs	javax_swing_JPanel;
    _jc_javax_swing_JComponent$sub_refs	javax_swing_JComponent;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_javax_swing_JComponent$sub_nonrefs	javax_swing_JComponent;
    _jc_javax_swing_JPanel$sub_nonrefs	javax_swing_JPanel;
    _jc_javax_swing_colorchooser_AbstractColorChooserPanel$sub_nonrefs	javax_swing_colorchooser_AbstractColorChooserPanel;
};

// Object instance structure
struct _jc_javax_swing_colorchooser_AbstractColorChooserPanel$object {
	_jc_javax_swing_colorchooser_AbstractColorChooserPanel$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_colorchooser_AbstractColorChooserPanel$vtype	*vtype;
	_jc_javax_swing_colorchooser_AbstractColorChooserPanel$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_colorchooser_AbstractColorChooserPanel$vtype _jc_javax_swing_colorchooser_AbstractColorChooserPanel$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_colorchooser_AbstractColorChooserPanel, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_colorchooser_AbstractColorChooserPanel$class_object;

#endif	/* _JC_javax_swing_colorchooser_AbstractColorChooserPanel_H_ */
